@@ -1,6 +1,8 @@
-'''Utilities related to ElasticBeanstalk deployment and management.
+"""
+Utilities related to ElasticBeanstalk deployment and management.
 This includes, but is not limited to: ES, s3, RDS, Auth0, and Foursight.
-'''
+"""
+
 from __future__ import print_function
 import subprocess
 import logging
@@ -13,11 +15,13 @@ import time
 from datetime import datetime
 from . import ff_utils
 from botocore.exceptions import ClientError
-from .misc_utils import PRINT
+from .misc_utils import PRINT, obsolete, remove_suffix
 from .env_utils import (
-    is_cgap_env, is_stg_or_prd_env, public_url_mappings, blue_green_mirror_env, get_standard_mirror_env
+    is_fourfront_env, is_cgap_env, is_stg_or_prd_env, public_url_mappings,
+    blue_green_mirror_env, get_standard_mirror_env,
 )
 
+
 logging.basicConfig()
 logger = logging.getLogger('logger')
 logger.setLevel(logging.INFO)
@@ -54,6 +58,9 @@ CGAP_GOLDEN_DB = 'fourfront-cgap.co3gwj7b7tpq.us-east-1.rds.amazonaws.com'
 # Although not visibly used in this repository, this variable is imported by Torb.
 GOLDEN_DB = FF_GOLDEN_DB
 
+# identifier for locating environment variables in EB config
+ENV_VARIABLE_NAMESPACE = 'aws:elasticbeanstalk:application:environment'
+
 REGION = 'us-east-1'
 
 
@@ -74,6 +81,13 @@ def delete_db(db_identifier, take_snapshot=True, allow_delete_prod=False):
     Returns:
         dict: boto3 response from delete_db_instance
     """
+    return _delete_db(db_identifier=db_identifier,
+                      take_snapshot=take_snapshot,
+                      allow_delete_prod=allow_delete_prod)
+
+
+def _delete_db(db_identifier, take_snapshot=True, allow_delete_prod=False):
+    """Internal version of delete_db."""
     # safety. Do not allow accidental programmatic deletion of webprod DB
     if 'prod' in db_identifier and not allow_delete_prod:
         raise Exception('Must set allow_delete_prod to True to delete RDS instance' % db_identifier)
@@ -101,6 +115,7 @@ def delete_db(db_identifier, take_snapshot=True, allow_delete_prod=False):
     return resp
 
 
+@obsolete
 def get_es_from_bs_config(env):
     """
     Given an ElasticBeanstalk environment name, get the corresponding
@@ -118,6 +133,7 @@ def get_es_from_bs_config(env):
             return item.split('=')[1].strip(':80')
 
 
+@obsolete
 def is_indexing_finished(env, prev_version=None, travis_build_id=None):
     """
     Checker function used with torb waitfor lambda; output must be standarized.
@@ -127,7 +143,7 @@ def is_indexing_finished(env, prev_version=None, travis_build_id=None):
     Args:
         env (str): ElasticBeanstalk environment name
         prev_version (str): optional EB version of the previous configuration
-        travis_build_id (int): optional ID for a Travis build
+        travis_build_id (int or str): optional ID for a Travis build
 
     Returns:
         bool, list: True if done, results from /counts page
@@ -149,7 +165,7 @@ def is_indexing_finished(env, prev_version=None, travis_build_id=None):
     if prev_version and beanstalk_info(env).get('VersionLabel') == prev_version:
         if travis_build_id:
             try:
-                trav_done, trav_details = is_travis_finished(travis_build_id)
+                trav_done, trav_details = is_travis_finished(str(travis_build_id))
             except Exception as exc:
                 # if the build failed, let the indexing check continue
                 if 'Build Failed' in str(exc):
@@ -198,7 +214,7 @@ def is_indexing_finished(env, prev_version=None, travis_build_id=None):
     return is_ready, totals
 
 
-def swap_cname(src, dest):
+def _swap_cname(src, dest):
     """
     Swap the CNAMEs of two ElasticBeanstalk (EB) environments, given by
     src and dest. Will restart the app servers after swapping.
@@ -222,20 +238,50 @@ def swap_cname(src, dest):
     client.restart_app_server(EnvironmentName=dest)
 
 
+def _create_foursight_new(dest_env):
+    """ Helper function that does what create_foursight_auto used to do but slightly differently """
+    fs = {  # noQA - PyCharm thinks the way this dictionary is set up could be simplified, but it's fine for now.
+        'dest_env': dest_env,
+        'bs_url': get_beanstalk_real_url(dest_env)
+    }
+
+    # Get information, pass to create_foursight
+    fs['fs_url'] = get_foursight_env(dest_env, fs['bs_url'])
+    fs['es_url'] = ff_utils.get_health_page(ff_env=dest_env)['elasticsearch']
+    fs['foursight'] = create_foursight(**fs)
+
+    # delete initial checks (? not clear why this was happening before)
+    if fs['foursight'].get('initial_checks'):
+        del fs['foursight']['initial_checks']
+
+    return fs
+
+
+def swap_cname(src, dest):
+    """ Does a CNAME swap and foursight configuration (pulled in from Torb)
+        NOTE: this is the mechanism by which CNAME swaps must occur as of 9/15/2020
+    """
+    _swap_cname(src, dest)
+    res_data = _create_foursight_new(src)
+    print('Updated foursight %s environment to use %s. Foursight response: %s'
+          % (res_data['fs_url'], res_data['dest_env'], res_data['foursight']))
+    res_stag = _create_foursight_new(dest)
+    print('Updated foursight %s environment to use %s. Foursight response: %s'
+          % (res_stag['fs_url'], res_stag['dest_env'], res_stag['foursight']))
+
+
 def _compute_prd_env_for_project(project):
-    '''
+    """
     Determines which ElasticBeanstalk environment is currently hosting
     data.4dnucleome.org. Requires IAM permissions for EB!
 
     Returns:
         str: EB environment name hosting data.4dnucleome
-    '''
+    """
     magic_cname = CGAP_MAGIC_CNAME if project == 'cgap' else FF_MAGIC_CNAME
     client = boto3.client('elasticbeanstalk', region_name=REGION)
     res = describe_beanstalk_environments(client, ApplicationName="4dn-web")
-    logger.info(res)
     for env in res['Environments']:
-        logger.info(env)
         if env.get('CNAME') == magic_cname:
             # we found data
             return env.get('EnvironmentName')
@@ -251,7 +297,7 @@ def compute_ff_stg_env():
     return get_standard_mirror_env(compute_ff_prd_env())
 
 
-whodaman = compute_ff_prd_env  # This naming is deprecated but retained for compatibility.
+whodaman = compute_ff_prd_env  # This naming is obsolete but retained for compatibility.
 
 
 def compute_cgap_prd_env():
@@ -264,6 +310,16 @@ def compute_cgap_stg_env():
     return get_standard_mirror_env(compute_cgap_prd_env())
 
 
+def compute_prd_env_for_env(envname):
+    """Given an environment, returns the name of the prod environment for its owning project."""
+    if is_cgap_env(envname):
+        return compute_cgap_prd_env()
+    elif is_fourfront_env(envname):
+        return compute_ff_prd_env()
+    else:
+        raise ValueError("Unknown environment: %s" % envname)
+
+
 def beanstalk_info(env):
     """
     Describe a ElasticBeanstalk environment given an environment name
@@ -290,7 +346,6 @@ def get_beanstalk_real_url(env):
     Returns:
         str: url of the ElasticBeanstalk environment
     """
-    url = ''
     urls = public_url_mappings(env)
 
     if env in urls:  # Special case handling of 'cgap', 'data', or 'staging' as an argument.
@@ -312,6 +367,62 @@ def get_beanstalk_real_url(env):
     return url
 
 
+def _get_beanstalk_configuration_settings(env):
+    """ Helper function for the below method (that is easy to mock for testing).
+        This function should not be called directly.
+        (relevant) syntax from boto3 docs:
+            {
+                'ConfigurationSettings': [
+                    {
+                        'SolutionStackName': 'string',
+                        'PlatformArn': 'string',
+                        'ApplicationName': 'string',
+                        'TemplateName': 'string',
+                        'Description': 'string',
+                        'EnvironmentName': 'string',
+                        'DeploymentStatus': 'deployed'|'pending'|'failed',
+                        'DateCreated': datetime(2015, 1, 1),
+                        'DateUpdated': datetime(2015, 1, 1),
+                        'OptionSettings': [
+                            {
+                                'ResourceName': 'string',
+                                'Namespace': 'string',
+                                'OptionName': 'string',
+                                'Value': 'string'
+                            },
+                        ]
+                    },
+                ]
+            }
+    """
+    try:
+        client = boto3.client('elasticbeanstalk', region_name=REGION)
+        config = client.describe_configuration_settings(ApplicationName='4dn-web', EnvironmentName=env)
+        # These are guaranteed to be present
+        [settings] = config['ConfigurationSettings']
+        options = settings['OptionSettings']
+        return options
+    except ClientError:
+        logger.error('Error encountered attempting to get environment settings for %s' % env)
+        return []
+
+
+def get_beanstalk_environment_variables(env):
+    """ Acquires the environment variables used to deploy the given environment.
+
+        VERY IMPORTANT NOTE: this function will echo *extremely sensitive* data if run.
+        Ensure that if you are using this you are not logging the output of this anywhere.
+    """
+    options = _get_beanstalk_configuration_settings(env)
+    env = {}
+    for option in options:
+        if 'Namespace' in option:
+            if option['Namespace'] == ENV_VARIABLE_NAMESPACE:
+                env[option['OptionName']] = option['Value']
+    return env
+
+
+@obsolete
 def is_beanstalk_ready(env):
     """
     Checker function used with torb waitfor lambda; output must be standarized.
@@ -384,6 +495,7 @@ def is_snapshot_ready(snapshot_name):
     return is_ready, resp['DBSnapshots'][0]['DBSnapshotIdentifier']
 
 
+@obsolete
 def is_es_ready(es_name):
     """
     Checker function used with torb waitfor lambda; output must be standarized.
@@ -458,7 +570,7 @@ def create_db_snapshot(db_identifier, snapshot_name):
     return response
 
 
-def create_db_from_snapshot(db_identifier, snapshot_name, delete_db=True):
+def create_db_from_snapshot(db_identifier, snapshot_name, delete_db_if_present=True):
     """
     Given an RDS instance indentifier and a snapshot ARN/name, create an RDS
     instance from the snapshot. If an instance already exists with the given
@@ -468,6 +580,7 @@ def create_db_from_snapshot(db_identifier, snapshot_name, delete_db=True):
     Args:
         db_identifier (str): RDS instance identifier
         snapshot_name (str): identifier/ARN of RDS snapshot to restore from
+        delete_db_if_present(bool): whether to drop the database on unwind
 
     Returns:
         str: resource ARN if successful, otherwise "Deleting"
@@ -483,11 +596,11 @@ def create_db_from_snapshot(db_identifier, snapshot_name, delete_db=True):
         )
     except ClientError:
         # Something went wrong
-        # Even if delete_db, never allow deletion of a db with 'webprod' in it
-        if delete_db:
+        # Even if delete_db, never allow deletion of a db with 'production' in it
+        if delete_db_if_present and 'production' not in db_identifier:
             # Drop target database with final snapshot
             try:
-                delete_db(db_identifier, True)
+                _delete_db(db_identifier, take_snapshot=True)
             except ClientError:
                 pass
             return "Deleting"
@@ -496,6 +609,7 @@ def create_db_from_snapshot(db_identifier, snapshot_name, delete_db=True):
     return response['DBInstance']['DBInstanceArn']
 
 
+@obsolete
 def is_travis_started(request_url):
     """
     Checker function used with torb waitfor lambda; output must be standarized.
@@ -529,13 +643,14 @@ def is_travis_started(request_url):
     return is_ready, details
 
 
+@obsolete
 def is_travis_finished(build_id):
     """
     Checker function used with torb waitfor lambda; output must be standarized.
     Check to see if a given travis build has passed
 
     Args:
-        build_id (str): Travis build identifier
+        build_id (int or str): Travis build identifier
 
     Returns:
         bool, dict: True if done, Travis response JSON
@@ -568,9 +683,11 @@ def is_travis_finished(build_id):
 
 
 def make_envvar_option(name, value):
-    return {'Namespace': 'aws:elasticbeanstalk:application:environment',
-            'OptionName': name,
-            'Value': value}
+    return {
+        'Namespace': 'aws:elasticbeanstalk:application:environment',
+        'OptionName': name,
+        'Value': value
+    }
 
 
 def get_bs_env(envname):
@@ -594,6 +711,7 @@ def get_bs_env(envname):
     return env_vars.split(',')
 
 
+@obsolete
 def update_bs_config(envname, template=None, keep_env_vars=False,
                      env_override=None):
     """
@@ -640,6 +758,7 @@ def update_bs_config(envname, template=None, keep_env_vars=False,
                                          OptionSettings=options)
 
 
+@obsolete
 def create_bs(envname, load_prod, db_endpoint, es_url, for_indexing=False):
     """
     XXX: Will not work currently, do NOT use on production
@@ -659,9 +778,13 @@ def create_bs(envname, load_prod, db_endpoint, es_url, for_indexing=False):
     Returns:
         dict: boto3 res from create_environment/update_environment
     """
+    # TODO (C4-280): Reconsider this and other functionality.
+    if is_stg_or_prd_env(envname):
+        raise RuntimeError("beanstalk_utils.create_bs is not approved for production use.")
+
     client = boto3.client('elasticbeanstalk', region_name=REGION)
 
-    # deterimine the configuration template for Elasticbeanstal
+    # determine the configuration template for Elasticbeanstalk
     template = 'fourfront-base'
     if for_indexing:
         template = 'fourfront-indexing'
@@ -679,6 +802,7 @@ def create_bs(envname, load_prod, db_endpoint, es_url, for_indexing=False):
     # logic for mirrorEsEnv, which is used to coordinate elasticsearch
     # changes between fourfront data and staging
     if 'fourfront-webprod' in envname:
+        # TODO: This code is obsolete and needs to be upgraded. For now, the use of this on production is disabled.
         other_env = 'fourfront-webprod2' if envname == 'fourfront-webprod' else 'fourfront-webprod'
         mirror_es = get_es_build_status(other_env, max_tries=3)
         if mirror_es:
@@ -775,6 +899,7 @@ def log_to_foursight(event, lambda_name='', overrides=None):
                             % (url, data, exc, res.text))
 
 
+@obsolete
 def create_foursight_auto(dest_env):
     """
     Call `create_foursight` to create a Foursight environment based off a
@@ -788,7 +913,9 @@ def create_foursight_auto(dest_env):
     Returns:
         dict: response from Foursight PUT /api/environments
     """
-    fs = {'dest_env': dest_env}
+    fs = {  # noQA - PyCharm thinks the way this dictionary is set up could be simplified, but it's fine for now.
+        'dest_env': dest_env
+    }
 
     # automatically determine info for FS environ creation
     fs['bs_url'] = get_beanstalk_real_url(dest_env)
@@ -848,14 +975,18 @@ def create_foursight(dest_env, bs_url, es_url, fs_url=None):
     # we want some url like thing
     if not bs_url.startswith('http'):
         bs_url = 'http://' + bs_url
-    if not bs_url.endswith("/"):
-        bs_url += "/"
+    if not bs_url.endswith('/'):
+        bs_url += '/'
 
-    es_url = es_url.rstrip(":80")
-    if not es_url.startswith("http"):
-        es_url = "https://" + es_url
-    if not es_url.endswith("/"):
-        es_url += "/"
+    if ':80' in es_url:
+        es_url = remove_suffix(':80', es_url)
+    elif ':443' in es_url:
+        es_url = remove_suffix(':443', es_url)
+
+    if not es_url.startswith('http'):
+        es_url = 'https://' + es_url
+    if not es_url.endswith('/'):
+        es_url += '/'
 
     # environments on foursight don't include fourfront
     if not fs_url:
@@ -864,10 +995,10 @@ def create_foursight(dest_env, bs_url, es_url, fs_url=None):
         fs_url = fs_url[len('fourfront-'):]
 
     foursight_url = FOURSIGHT_URL + 'environments/' + fs_url
-    payload = {"fourfront": bs_url,  "es": es_url, "ff_env": dest_env}
+    payload = {'fourfront': bs_url, 'es': es_url, 'ff_env': dest_env}
 
     ff_auth = os.environ.get('FS_AUTH')
-    headers = {'content-type': "application/json", 'Authorization': ff_auth}
+    headers = {'content-type': 'application/json', 'Authorization': ff_auth}
     res = requests.put(foursight_url, data=json.dumps(payload), headers=headers)
     try:
         return res.json()
@@ -877,6 +1008,7 @@ def create_foursight(dest_env, bs_url, es_url, fs_url=None):
                         % (foursight_url, payload, exc, res.text))
 
 
+@obsolete
 def create_new_es(new):
     """
     Create a new Elasticsearch domain with given name. See the
@@ -913,6 +1045,7 @@ def create_new_es(new):
     return resp
 
 
+@obsolete
 def get_es_build_status(new, max_tries=None):
     """
     Check the build status of an Elasticsearch instance with given name.
@@ -953,6 +1086,7 @@ def get_es_build_status(new, max_tries=None):
 #########################################################################
 
 
+@obsolete
 def add_es(new, force_new=False):
     """
     Either gets information on an existing Elasticsearch instance
@@ -1007,6 +1141,7 @@ def delete_es_domain(env_name):
         PRINT("es domain %s not found, skipping" % env_name)
 
 
+@obsolete
 def clone_bs_env_cli(old, new, load_prod, db_endpoint, es_url):
     """
     Use the eb command line client to clone an ElasticBeanstalk environment
@@ -1084,6 +1219,8 @@ def delete_s3_buckets(env_name):
         'elasticbeanstalk-%s-files' % env_name,
         'elasticbeanstalk-%s-wfoutput' % env_name,
         'elasticbeanstalk-%s-system' % env_name,
+        'elasticbeanstalk-%s-metadata-bundles' % env_name,
+        # note that tibanna logs are shared so are not so easy to delete
     ]
 
     s3 = boto3.resource('s3')
@@ -1092,7 +1229,7 @@ def delete_s3_buckets(env_name):
         try:
             s3.Bucket(bucket).objects.delete()
             s3.Bucket(bucket).delete()
-        except:  # noqa: E722
+        except Exception:  # noqa: E722
             PRINT(bucket + " not found skipping...")
 
 
@@ -1193,24 +1330,24 @@ def auth0_client_update(url):
         None
     """
     # generate a jwt to validate future requests
-    client = os.environ["Auth0Client"]
-    secret = os.environ["Auth0Secret"]
-    payload = {"grant_type": "client_credentials",
-               "client_id": client,
-               "client_secret": secret,
-               "audience": "https://hms-dbmi.auth0.com/api/v2/"}
-    headers = {'content-type': "application/json"}
-    res = requests.post("https://hms-dbmi.auth0.com/oauth/token",
+    client = os.environ['Auth0Client']
+    secret = os.environ['Auth0Secret']
+    payload = {'grant_type': 'client_credentials',
+               'client_id': client,
+               'client_secret': secret,
+               'audience': 'https://hms-dbmi.auth0.com/api/v2/'}
+    headers = {'content-type': 'application/json'}
+    res = requests.post('https://hms-dbmi.auth0.com/oauth/token',
                         data=json.dumps(payload),
                         headers=headers)
     jwt = res.json()['access_token']
 
-    client_url = "https://hms-dbmi.auth0.com/api/v2/clients/%s" % client
+    client_url = 'https://hms-dbmi.auth0.com/api/v2/clients/%s' % client
     headers['authorization'] = 'Bearer %s' % jwt
 
     get_res = requests.get(client_url + '?fields=callbacks', headers=headers)
     callbacks = get_res.json()['callbacks']
-    callbacks.append("http://" + url)
+    callbacks.append('http://' + url)
     client_data = {'callbacks': callbacks}
 
     update_res = requests.patch(client_url, data=json.dumps(client_data), headers=headers)
@@ -1229,18 +1366,18 @@ def auth0_client_remove(url):
         None
     """
     # generate a jwt to validate future requests
-    client = os.environ["Auth0Client"]
-    secret = os.environ["Auth0Secret"]
-    payload = {"grant_type": "client_credentials",
-               "client_id": client,
-               "client_secret": secret,
-               "audience": "https://hms-dbmi.auth0.com/api/v2/"}
-    headers = {'content-type': "application/json"}
-    res = requests.post("https://hms-dbmi.auth0.com/oauth/token",
+    client = os.environ['Auth0Client']
+    secret = os.environ['Auth0Secret']
+    payload = {'grant_type': 'client_credentials',
+               'client_id': client,
+               'client_secret': secret,
+               'audience': 'https://hms-dbmi.auth0.com/api/v2/'}
+    headers = {'content-type': 'application/json'}
+    res = requests.post('https://hms-dbmi.auth0.com/oauth/token',
                         data=json.dumps(payload),
                         headers=headers)
     jwt = res.json()['access_token']
-    client_url = "https://hms-dbmi.auth0.com/api/v2/clients/%s" % client
+    client_url = 'https://hms-dbmi.auth0.com/api/v2/clients/%s' % client
     headers['authorization'] = 'Bearer %s' % jwt
 
     get_res = requests.get(client_url + '?fields=callbacks', headers=headers)
@@ -1249,7 +1386,7 @@ def auth0_client_remove(url):
     try:
         idx = callbacks.index(full_url)
     except ValueError:
-        PRINT(full_url + " Not in auth0 auth, doesn't need to be removed")
+        PRINT(full_url + ' Not in auth0 auth, doesn\'t need to be removed')
         return
     if idx:
         callbacks.pop(idx)
@@ -1296,9 +1433,9 @@ def copy_s3_buckets(new, old):
     # get rid of system bucket
     new_buckets.pop()
     for old, new in zip(old_buckets, new_buckets):
-        oldb = "s3://%s" % old
-        newb = "s3://%s" % new
-        PRINT("copying data from old %s to new %s" % (oldb, newb))
+        oldb = 's3://%s' % old
+        newb = 's3://%s' % new
+        PRINT('copying data from old %s to new %s' % (oldb, newb))
         subprocess.call(['aws', 's3', 'sync', oldb, newb])
 
 
@@ -1325,7 +1462,7 @@ def clone_beanstalk_command_line(old, new, prod=False, copy_s3=False):
     Returns:
         None
     """
-    if 'Auth0Client' not in os.environ or "Auth0Secret" not in os.environ:
+    if 'Auth0Client' not in os.environ or 'Auth0Secret' not in os.environ:
         PRINT('Must set Auth0Client and Auth0Secret env variables! Exiting...')
         return
     PRINT('### eb status (START)')
@@ -1338,26 +1475,26 @@ def clone_beanstalk_command_line(old, new, prod=False, copy_s3=False):
                      " This includes s3, ES, RDS, and Auth0 callbacks. If you "
                      "are sure, type the new env name to confirm: " % (new, old))
     if str(name) != new:
-        PRINT("Could not confirm env. Exiting...")
+        PRINT('Could not confirm env. Exiting...')
         return
-    PRINT("### start build ES service")
+    PRINT('### start build ES service')
     add_es(new)
-    PRINT("### create the s3 buckets")
+    PRINT('### create the s3 buckets')
     create_s3_buckets(new)
-    PRINT("### create snapshot and copy database")
+    PRINT('### create snapshot and copy database')
     db_endpoint = snapshot_and_clone_db(old, new)
-    PRINT("### waiting for ES service")
+    PRINT('### waiting for ES service')
     es_endpoint = get_es_build_status(new)
-    PRINT("### clone elasticbeanstalk envrionment")
+    PRINT('### clone elasticbeanstalk envrionment')
     # TODO, can we pass in github commit id here?
     clone_bs_env_cli(old, new, prod, db_endpoint, es_endpoint)
-    PRINT("### allow auth-0 requests")
+    PRINT('### allow auth-0 requests')
     add_to_auth0_client(new)
     if copy_s3 is True:
-        PRINT("### copy contents of s3")
+        PRINT('### copy contents of s3')
         copy_s3_buckets(new, old)
-    PRINT("### All done! It may take some time for the beanstalk env to finish"
-          " initialization. You may want to deploy the most current FF branch.")
+    PRINT('### All done! It may take some time for the beanstalk env to finish'
+          ' initialization. You may want to deploy the most current FF branch.')
 
 
 def delete_beanstalk_command_line(env):
@@ -1379,7 +1516,7 @@ def delete_beanstalk_command_line(env):
     Returns:
         None
     """
-    if 'Auth0Client' not in os.environ or "Auth0Secret" not in os.environ:
+    if 'Auth0Client' not in os.environ or 'Auth0Secret' not in os.environ:
         PRINT('Must set Auth0Client and Auth0Secret env variables! Exiting...')
         return
     PRINT('### eb status (START)')
@@ -1388,20 +1525,20 @@ def delete_beanstalk_command_line(env):
         PRINT('This command must be called from an eb initialized repo! Exiting...')
         return
     PRINT('### eb status (END)')
-    name = use_input("This will totally blow away the environment, including s3,"
-                     "ES, RDS, and Auth0 callbacks. If you are sure, type the "
-                     "env name to confirm: ")
+    name = use_input('This will totally blow away the environment, including s3,'
+                     'ES, RDS, and Auth0 callbacks. If you are sure, type the '
+                     'env name to confirm: ')
     if str(name) != env:
-        PRINT("Could not confirm env. Exiting...")
+        PRINT('Could not confirm env. Exiting...')
         return
-    PRINT("### Removing access to auth0")
+    PRINT('### Removing access to auth0')
     remove_from_auth0_client(env)
-    PRINT("### Deleting beanstalk enviornment")
+    PRINT('### Deleting beanstalk enviornment')
     delete_bs_env_cli(env)
-    PRINT("### Delete contents of s3")
+    PRINT('### Delete contents of s3')
     delete_s3_buckets(env)
-    PRINT("### Delete es domain")
+    PRINT('### Delete es domain')
     delete_es_domain(env)
-    PRINT("### Delete database")
+    PRINT('### Delete database')
     delete_db(env)
     PRINT('### All done!')
