@@ -40,6 +40,7 @@ from .env_utils import (
     FF_ENV_INDEXER, CGAP_ENV_INDEXER, is_indexer_env, indexer_env_for_env,
 )
 from .misc_utils import PRINT, Retry, apply_dict_overrides, override_environ
+from .s3_utils import s3Utils
 
 
 # constants associated with EB-related APIs
@@ -103,6 +104,7 @@ class EBDeployer:
             repo.archive(fp, format='zip')
         return zip_location
 
+    # noinspection PyUnresolvedReferences - PyCharm has bogus issues with the boto3.client reference here.
     @classmethod
     def upload_application_to_s3(cls, zip_location):
         """ Uploads the zip file at zip_location to the specified S3 bucket
@@ -399,11 +401,23 @@ class IniFileManager:
     INI_FILE_NAME = "production.ini"
     PYPROJECT_FILE_NAME = None
 
+    # For APP, a subclass may optionally declare a value of 'cgap' or 'fourfront'
+    APP_KIND = None
+
+    # For ORCHESTRATED, a subclass may optinally declare a value of True or False,
+    # or this can be specified on the command line
+    APP_ORCHESTRATED = None
+
     @classmethod
-    def build_ini_file_from_template(cls, template_file_name, init_file_name,
-                                     bs_env=None, bs_mirror_env=None, s3_bucket_env=None,
-                                     data_set=None, es_server=None, es_namespace=None,
-                                     indexer=None, index_server=None, sentry_dsn=None):
+    def build_ini_file_from_template(cls, template_file_name, init_file_name, *,
+                                     bs_env=None, bs_mirror_env=None, s3_bucket_org=None, s3_bucket_env=None,
+                                     data_set=None, es_server=None, es_namespace=None, identity=None,
+                                     indexer=None, index_server=None, sentry_dsn=None, tibanna_output_bucket=None,
+                                     application_bucket_prefix=None, foursight_bucket_prefix=None,
+                                     auth0_client=None, auth0_secret=None,
+                                     file_upload_bucket=None, file_wfout_bucket=None,
+                                     blob_bucket=None, system_bucket=None, metadata_bundles_bucket=None):
+
         """
         Builds a .ini file from a given template file.
 
@@ -412,24 +426,55 @@ class IniFileManager:
             init_file_name (str): The name of the .ini file to build.
             bs_env (str): The ElasticBeanstalk environment name for which this .ini file should work.
             bs_mirror_env (str): The name of the ElasticBeanstalk environment that acts as a blue/green mirror.
+            s3_bucket_org (str): A token that uniquely identifies your organization for use in all s3 bucket names.
+              In the original CGAP, this token was 'elasticbeanstalk'. Going forward, each account must choose
+              a token that uniquely identifies the organization instead. The default of 'elasticbeanstalk'
+              is necessary for legacy reasons but will fail for any other organization than the original HMS/DBMI use.
+              You really need to specify this argument or use the ENCODED_S3_BUCKET_ORG environment variable.
             s3_bucket_env (str): Environment name that is part of the s3 bucket name. (Usually defaults properly.)
             data_set (str): An identifier for data to load (either 'prod' for prd/stg envs, or 'test' for others)
             es_server (str): The server name (or server:port) for the ElasticSearch server.
             es_namespace (str): The ElasticSearch namespace to use (probably but not necessarily same as bs_env).
+            identity (str): The AWS application configuration key that represents the current environment.
             indexer (bool): Whether or not we are building an ini file for an indexer.
             index_server (bool): Whether or not we are building an ini file for an index server.
+            sentry_dsn (str): A sentry DSN specifier, or the empty string if none is desired.
+            tibanna_output_bucket (str): Specific name of the bucket to use on S3 for tibanna logs.
+            application_bucket_prefix (str): An application bucket prefix to use, overriding the default one.
+            foursight_bucket_prefix (str): A foursight bucket prefix to use, overriding the default one.
+            auth0_client (str): A string identifying the auth0 client application.
+            auth0_secret (str): A string secret that is passed with the auth0_client to authenticate that client.
+            file_upload_bucket (str): Specific name of the bucket to use on S3 for file upload data.
+            file_wfout_bucket (str): Specific name of the bucket to use on S3 for wfout data.
+            blob_bucket (str): Specific name of the bucket to use on S3 for blob data.
+            system_bucket (str): Specific name of the bucket to use on S3 for system data.
+            metadata_bundles_bucket (str): Specific name of the bucket to use on S3 for metadata bundles data.
         """
         with io.open(init_file_name, 'w') as init_file_fp:
             cls.build_ini_stream_from_template(template_file_name=template_file_name,
                                                init_file_stream=init_file_fp,
                                                bs_env=bs_env,
                                                bs_mirror_env=bs_mirror_env,
+                                               s3_bucket_org=s3_bucket_org,
                                                s3_bucket_env=s3_bucket_env,
                                                data_set=data_set,
                                                es_server=es_server,
                                                es_namespace=es_namespace,
+                                               identity=identity,
                                                indexer=indexer,
-                                               sentry_dsn=sentry_dsn)
+                                               index_server=index_server,
+                                               sentry_dsn=sentry_dsn,
+                                               tibanna_output_bucket=tibanna_output_bucket,
+                                               application_bucket_prefix=application_bucket_prefix,
+                                               foursight_bucket_prefix=foursight_bucket_prefix,
+                                               auth0_client=auth0_client,
+                                               auth0_secret=auth0_secret,
+                                               file_upload_bucket=file_upload_bucket,
+                                               file_wfout_bucket=file_wfout_bucket,
+                                               blob_bucket=blob_bucket,
+                                               system_bucket=system_bucket,
+                                               metadata_bundles_bucket=metadata_bundles_bucket,
+                                               )
 
     # Ref: https://stackoverflow.com/questions/19911123/how-can-you-get-the-elastic-beanstalk-application-version-in-your-application  # noqa: E501
     EB_MANIFEST_FILENAME = "/opt/elasticbeanstalk/deploy/manifest"
@@ -471,11 +516,21 @@ class IniFileManager:
 
     AUTO_INDEX_SERVER_TOKEN = "__index_server"
 
+    LEGACY_APPLICATION_BUCKET_ORG = s3Utils.EB_PREFIX                        # = "elasticbeanstalk"
+    LEGACY_APPLICATION_BUCKET_PREFIX = LEGACY_APPLICATION_BUCKET_ORG + "-"   # = "elasticbeanstalk-"
+    LEGACY_TIBANNA_OUTPUT_BUCKET = s3Utils.TIBANNA_OUTPUT_BUCKET_TEMPLATE    # = "tibanna-output"
+    LEGACY_FOURSIGHT_BUCKET_PREFIX = "foursight-"
+
     @classmethod
-    def build_ini_stream_from_template(cls, template_file_name, init_file_stream,
-                                       bs_env=None, bs_mirror_env=None, s3_bucket_env=None, data_set=None,
-                                       es_server=None, es_namespace=None, indexer=None, index_server=None,
-                                       sentry_dsn=None):
+    def build_ini_stream_from_template(cls, template_file_name, init_file_stream, *,
+                                       bs_env=None, bs_mirror_env=None, s3_bucket_org=None, s3_bucket_env=None,
+                                       data_set=None, es_server=None, es_namespace=None, identity=None,
+                                       indexer=None, index_server=None, sentry_dsn=None, tibanna_output_bucket=None,
+                                       application_bucket_prefix=None, foursight_bucket_prefix=None,
+                                       auth0_client=None, auth0_secret=None,
+                                       file_upload_bucket=None,
+                                       file_wfout_bucket=None, blob_bucket=None, system_bucket=None,
+                                       metadata_bundles_bucket=None):
         """
         Sends output to init_file_stream corresponding to the data noe would want in an ini file
         for the given template_file_name and available environment variables.
@@ -485,13 +540,25 @@ class IniFileManager:
             init_file_stream: A stream to send output to.
             bs_env: A beanstalk environment.
             bs_mirror_env: A beanstalk environment.
+            s3_bucket_org: Short name token unique to the organization, for use as a low-tech namespace separator.
             s3_bucket_env: Environment name that is part of the s3 bucket name. (Usually defaults properly.)
             data_set: 'test' or 'prod'. Default is 'test' unless bs_env is a staging or production environment.
             es_server: The name of an es server to use.
             es_namespace: The namespace to use on the es server. If None, this uses the bs_env.
+            identity (str): The AWS application configuration key that represents the current environment.
             indexer: Whether or not we are building an ini file for an indexer.
             index_server: Whether or not we are building an ini file for an index server.
-            sentry_dsn: A sentry DSN specifier, or the empty string if none is desired.
+            sentry_dsn (str): A sentry DSN specifier, or the empty string if none is desired.
+            tibanna_output_bucket (str): Specific name of the bucket to use on S3 for tibanna logs.
+            application_bucket_prefix (str): An application bucket prefix to use, overriding the default one.
+            foursight_bucket_prefix (str): A foursight bucket prefix to use, overriding the default one.
+            auth0_client (str): A string identifying the auth0 client application.
+            auth0_secret (str): A string secret that is passed with the auth0_client to authenticate that client.
+            file_upload_bucket (str): Specific name of the bucket to use on S3 for file upload data.
+            file_wfout_bucket (str): Specific name of the bucket to use on S3 for wfout data.
+            blob_bucket (str): Specific name of the bucket to use on S3 for blob data.
+            system_bucket (str): Specific name of the bucket to use on S3 for system data.
+            metadata_bundles_bucket (str): Specific name of the bucket to use on S3 for metadata bundles data.
 
         Returns: None
 
@@ -500,11 +567,66 @@ class IniFileManager:
         es_server = es_server or os.environ.get('ENCODED_ES_SERVER', "MISSING_ENCODED_ES_SERVER")
         bs_env = bs_env or os.environ.get("ENCODED_BS_ENV", "MISSING_ENCODED_BS_ENV")
         bs_mirror_env = bs_mirror_env or os.environ.get("ENCODED_BS_MIRROR_ENV", get_standard_mirror_env(bs_env)) or ""
+        s3_bucket_org = (s3_bucket_org
+                         or os.environ.get("ENCODED_S3_BUCKET_ORG")
+                         or ("MISSING_ENCODED_S3_BUCKET_ORG"
+                             if cls.APP_ORCHESTRATED
+                             else cls.LEGACY_APPLICATION_BUCKET_ORG))
+        application_bucket_prefix = (application_bucket_prefix
+                                     or os.environ.get("ENCODED_APPLICATION_BUCKET_PREFIX")
+                                     or ("MISSING_ENCODED_APPLICATION_BUCKET_PREFIX"
+                                         if cls.APP_ORCHESTRATED
+                                         else cls.LEGACY_APPLICATION_BUCKET_PREFIX))
+        foursight_bucket_prefix = (foursight_bucket_prefix
+                                   or os.environ.get("ENCODED_FOURSIGHT_BUCKET_PREFIX")
+                                   or ("MISSING_ENCODED_FOURSIGHT_BUCKET_PREFIX"
+                                       if cls.APP_ORCHESTRATED
+                                       else cls.LEGACY_FOURSIGHT_BUCKET_PREFIX))
         s3_bucket_env = s3_bucket_env or os.environ.get("ENCODED_S3_BUCKET_ENV", get_bucket_env(bs_env))
-        data_set = data_set or os.environ.get("ENCODED_DATA_SET",
-                                              data_set_for_env(bs_env) or "MISSING_ENCODED_DATA_SET")
+        data_set = (data_set
+                    or os.environ.get("ENCODED_DATA_SET")
+                    or data_set_for_env(bs_env)
+                    or "MISSING_ENCODED_DATA_SET")
         es_namespace = es_namespace or os.environ.get("ENCODED_ES_NAMESPACE", bs_env)
+        identity = identity or os.environ.get("ENCODED_IDENTITY", "")
         sentry_dsn = sentry_dsn or os.environ.get("ENCODED_SENTRY_DSN", "")
+        auth0_client = auth0_client or os.environ.get("ENCODED_AUTH0_CLIENT", "")
+        auth0_secret = auth0_secret or os.environ.get("ENCODED_AUTH0_SECRET", "")
+
+        # corresponds to s3Utils legacy "elasticbeanstalk-%s-files"
+        file_upload_bucket = (file_upload_bucket
+                              or os.environ.get("ENCODED_FILE_UPLOAD_BUCKET")
+                              or f"{application_bucket_prefix}{s3_bucket_env}-{s3Utils.RAW_BUCKET_SUFFIX}")
+
+        # corresponds to s3Utils legacy "elasticbeanstalk-%s-wfoutput"
+        file_wfout_bucket = (file_wfout_bucket
+                             or os.environ.get("ENCODED_FILE_WFOUT_BUCKET")
+                             or f"{application_bucket_prefix}{s3_bucket_env}-{s3Utils.OUTFILE_BUCKET_SUFFIX}")
+
+        # corresponds to s3Utils legacy "elasticbeanstalk-%s-blobs"
+        blob_bucket = (blob_bucket
+                       or os.environ.get("ENCODED_BLOB_BUCKET")
+                       or f"{application_bucket_prefix}{s3_bucket_env}-{s3Utils.BLOB_BUCKET_SUFFIX}")
+
+        # corresponds to s3Utils legacy "elasticbeanstalk-%s-system"
+        system_bucket = (system_bucket
+                         or os.environ.get("ENCODED_SYSTEM_BUCKET")
+                         or f"{application_bucket_prefix}{s3_bucket_env}-{s3Utils.SYS_BUCKET_SUFFIX}")
+
+        # corresponds to s3Utils legacy "elasticbeanstalk-%s-metadata-bundles"
+        metadata_bundles_bucket = (metadata_bundles_bucket
+                                   or os.environ.get("ENCODED_METADATA_BUNDLES_BUCKET")
+                                   or f"{application_bucket_prefix}{s3_bucket_env}-{s3Utils.METADATA_BUCKET_SUFFIX}")
+
+        # corresponses to s3Utils legacy "tibanna-output" (no prefix)
+        tibanna_output_bucket = (tibanna_output_bucket
+                                 or os.environ.get("ENCODED_TIBANNA_OUTPUT_BUCKET")
+                                 or (f"{application_bucket_prefix}{s3Utils.TIBANNA_OUTPUT_BUCKET_SUFFIX}"
+                                     if cls.APP_ORCHESTRATED
+                                     else cls.LEGACY_TIBANNA_OUTPUT_BUCKET))
+        app_kind = cls.APP_KIND or "unknown"
+        app_deployment = "orchestrated" if cls.APP_ORCHESTRATED else "beanstalk"
+
         # Set ENCODED_INDEXER to 'true' to deploy an indexer.
         # If the value is missing, the empty string, or any other thing besides 'true' (in any case),
         # this value will default to the empty string, causing the line not to appear in the output file
@@ -533,6 +655,8 @@ class IniFileManager:
         index_server = "true" if index_server else ""  # this will omit the line if it's going to be False
 
         extra_vars = {
+            'APP_KIND': app_kind,  # "cgap" or "fourfront"
+            'APP_DEPLOYMENT': app_deployment,  # "orchestrated" or "elasticbeanstalk"
             'APP_VERSION': app_version,
             'PROJECT_VERSION': toml.load(cls.PYPROJECT_FILE_NAME)['tool']['poetry']['version'],
             'SNOVAULT_VERSION': pkg_resources.get_distribution("dcicsnovault").version,
@@ -540,12 +664,24 @@ class IniFileManager:
             'ES_SERVER': es_server,
             'BS_ENV': bs_env,
             'BS_MIRROR_ENV': bs_mirror_env,
+            'S3_BUCKET_ORG': s3_bucket_org,
             'S3_BUCKET_ENV': s3_bucket_env,
             'DATA_SET': data_set,
             'ES_NAMESPACE': es_namespace,
+            'IDENTITY': identity,
             'INDEXER': indexer,
             'INDEX_SERVER': index_server,
             'SENTRY_DSN': sentry_dsn,
+            'TIBANNA_OUTPUT_BUCKET': tibanna_output_bucket,
+            'AUTH0_CLIENT': auth0_client,
+            'AUTH0_SECRET': auth0_secret,
+            'FILE_UPLOAD_BUCKET': file_upload_bucket,
+            'FILE_WFOUT_BUCKET': file_wfout_bucket,
+            'BLOB_BUCKET': blob_bucket,
+            'SYSTEM_BUCKET': system_bucket,
+            'METADATA_BUNDLES_BUCKET': metadata_bundles_bucket,
+            'APPLICATION_BUCKET_PREFIX': application_bucket_prefix,
+            'FOURSIGHT_BUCKET_PREFIX': foursight_bucket_prefix,
         }
 
         # if we specify an indexer name for bs_env, we did the deployment wrong and should bail
@@ -636,6 +772,9 @@ class IniFileManager:
             parser.add_argument("--bs_mirror_env",
                                 help="the name of the mirror of the ElasticBeanstalk environment name",
                                 default=None)
+            parser.add_argument("--s3_bucket_org",
+                                help="a token that uniquely identifies your organization for use in all s3 buckets",
+                                default=None)
             parser.add_argument("--s3_bucket_env",
                                 help="name of env to use in s3 bucket name, usually defaulted without specifying",
                                 default=None)
@@ -649,6 +788,9 @@ class IniFileManager:
             parser.add_argument("--es_namespace",
                                 help="an ElasticSearch namespace",
                                 default=None)
+            parser.add_argument("--identity",
+                                help="the AWS application configuration key that represents the current environment",
+                                default=None)
             parser.add_argument("--indexer",
                                 help="whether this server does indexing at all",
                                 choices=["true", "false"],
@@ -660,6 +802,43 @@ class IniFileManager:
             parser.add_argument("--sentry_dsn",
                                 help="a sentry DSN",
                                 default=None)
+            parser.add_argument("--tibanna_output_bucket",
+                                help="the name of a Tibanna logs bucket to use",
+                                default=None)
+            parser.add_argument("--application_bucket_prefix",
+                                help="an application bucket prefix to use, overriding the default one",
+                                default=None)
+            parser.add_argument("--foursight_bucket_prefix",
+                                help="a foursight bucket prefix to use, overriding the default one",
+                                default=None)
+            parser.add_argument("--auth0_client",
+                                help="an auth0 client identifier token",
+                                default=None)
+            parser.add_argument("--auth0_secret",
+                                help="an auth0 secret to authorize auth0_client",
+                                default=None)
+            parser.add_argument("--file_upload_bucket",
+                                help="the name of the file upload bucket to use",
+                                default=None)
+            parser.add_argument("--file_wfout_bucket",
+                                help="the name of the file wfout bucket to use",
+                                default=None)
+            parser.add_argument("--blob_bucket",
+                                help="the name of a blob bucket to use",
+                                default=None)
+            parser.add_argument("--system-bucket",
+                                help="the name of a system bucket to use",
+                                default=None)
+            parser.add_argument("--metadata_bundles_bucket",
+                                help="the name of a metadata bundles bucket to use",
+                                default=None)
+            # In case we need to deal with this in a more dynamic way...
+            # parser.add_argument("--orchestrated", action="store_true", dest="orchestrated",
+            #                     help="Declares that the deploy is an orchestrated deploy, not a legacy deploy",
+            #                     default=cls.ORCHESTRATED)
+            # parser.add_argument("--legacy", action="store_false", dest="orchestrated",
+            #                     help="Declares that the deploy is a legacy deploy, not an orchestrated deploy",
+            #                     default=cls.ORCHESTRATED)
             args = parser.parse_args()
             template_file_name = (cls.any_environment_template_filename()
                                   if args.use_any
@@ -669,15 +848,72 @@ class IniFileManager:
             # print("ini_file_name=", ini_file_name)
             cls.build_ini_file_from_template(template_file_name, ini_file_name,
                                              bs_env=args.bs_env, bs_mirror_env=args.bs_mirror_env,
-                                             s3_bucket_env=args.s3_bucket_env, data_set=args.data_set,
+                                             s3_bucket_org=args.s3_bucket_org, s3_bucket_env=args.s3_bucket_env,
+                                             data_set=args.data_set,
                                              es_server=args.es_server, es_namespace=args.es_namespace,
                                              indexer=args.indexer, index_server=args.index_server,
-                                             sentry_dsn=args.sentry_dsn)
+                                             identity=args.identity,
+                                             sentry_dsn=args.sentry_dsn,
+                                             tibanna_output_bucket=args.tibanna_output_bucket,
+                                             application_bucket_prefix=args.application_bucket_prefix,
+                                             foursight_bucket_prefix=args.foursight_bucket_prefix,
+                                             auth0_client=args.auth0_client,
+                                             auth0_secret=args.auth0_secret,
+                                             file_upload_bucket=args.file_upload_bucket,
+                                             file_wfout_bucket=args.file_wfout_bucket,
+                                             blob_bucket=args.blob_bucket, system_bucket=args.system_bucket,
+                                             metadata_bundles_bucket=args.metadata_bundles_bucket)
         except Exception as e:
             PRINT("Error (%s): %s" % (e.__class__.__name__, e))
             sys.exit(1)
 
 
+class BasicCGAPIniFileManager(IniFileManager):
+    """
+    Any IniFileManager used by CGAP should use this class to get better defaulting.
+    This class exists mostly for type inclusion. For actual use, you probably want one of its subclasses.
+    """
+    APP_KIND = 'cgap'
+
+
+class BasicLegacyCGAPIniFileManager(BasicCGAPIniFileManager):
+    """
+    A class of IniFileManager for producing a CGAP-style production.ini in a legacy (beanstalk) context.
+    """
+    APP_ORCHESTRATED = False
+
+
+class BasicOrchestratedCGAPIniFileManager(BasicCGAPIniFileManager):
+    """
+    A class of IniFileManager for producing a CGAP-style production.ini in a CloudFormation-orechstrated context.
+    """
+    APP_ORCHESTRATED = True
+
+
+class BasicFourfrontIniFileManager(IniFileManager):
+    """
+    Any IniFileManager used by Fourfront should use this class to get better defaulting.
+    This class exists mostly for type inclusion. For actual use, you probably want one of its subclasses.
+    """
+    APP_KIND = 'fourfront'
+
+
+class BasicLegacyFourfrontIniFileManager(BasicFourfrontIniFileManager):
+    """
+    A class of IniFileManager for producing a Fourfront-style production.ini in a legacy (beanstalk) context.
+    NOTE: For now this is really the only such context, but eventually there may be an orchestrated version as well.
+    """
+    APP_ORCHESTRATED = False
+
+
+class BasicOrchestratedFourfrontIniFileManager(BasicFourfrontIniFileManager):
+    """
+    A class of IniFileManager for producing a Fourfront-style production.ini in a CloudFormation-orechstrated context.
+    NOTE: For now there is no such context, but this is intended to be thinking forward.
+    """
+    APP_ORCHESTRATED = True
+
+
 # The name Deployer is deprecated. Please use IniFileManager instead of Deployer.
 Deployer = IniFileManager
 
@@ -750,7 +986,8 @@ class CreateMappingOnDeployManager:
         else:
             description = "an unrecognized environment"
         log.info('Environment %s is %s. Processing mode: %s'
-                 % (env, description, cls._summarize_deploy_options(deploy_cfg)))
+                 % (env, description, # noQA - PyCharm wrongly worries description might be unassigned
+                    cls._summarize_deploy_options(deploy_cfg)))
         return deploy_cfg
 
     @staticmethod
